@@ -2,7 +2,7 @@ package HTTP::MobileAgent::DoCoMo;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = 0.11;
+$VERSION = 0.12;
 
 use base qw(HTTP::MobileAgent);
 
@@ -23,7 +23,7 @@ $HTMLVerMap = [
     qr/[DFNP]501i/ => '1.0',
     qr/502i|821i|209i|691i|(F|N|P|KO)210i|^F671i$/ => '2.0',
     qr/(D210i|SO210i)|503i|211i|SH251i|692i|200[12]|2101V/ => '3.0',
-    qr/504i|251i|^F671iS$|^F661i$|212i|2051|2102V/ => '4.0',
+    qr/504i|251i|^F671iS$|^F661i$|212i|2051|2102V|2701/ => '4.0',
     qr/eggy|P751v/ => '3.2',
     qr/505i/ => '5.0',
 ];
